package com.inspect.metadata.montdata.service.impl;

import com.inspect.metadata.montdata.domain.BasedataMontPatDevStaData;
import com.inspect.metadata.montdata.mapper.BasedataMontPatDevStaDataMapper;
import com.inspect.metadata.montdata.service.IBasedataMontPatDevStaDataService;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
public class BasedataMontPatDevStaDataServiceImpl implements IBasedataMontPatDevStaDataService {
    @Resource
    private BasedataMontPatDevStaDataMapper basedataMontPatdevstadataMapper;

    public BasedataMontPatDevStaData selectBasedataMontPatDevStaDataByMontPatDevStaDataId(Long montPatDevStaDataId) {
        return this.basedataMontPatdevstadataMapper.selectBasedataMontPatDevStaDataByMontPatDevStaDataId(montPatDevStaDataId);
    }

    public List<BasedataMontPatDevStaData> selectBasedataMontPatDevStaDataList(BasedataMontPatDevStaData basedataMontPatDevStaData) {
        return this.basedataMontPatdevstadataMapper.selectBasedataMontPatDevStaDataList(basedataMontPatDevStaData);
    }

    public int insertBasedataMontPatDevStaData(BasedataMontPatDevStaData basedataMontPatDevStaData) {
        return this.basedataMontPatdevstadataMapper.insertBasedataMontPatDevStaData(basedataMontPatDevStaData);
    }

    public int updateBasedataMontPatDevStaData(BasedataMontPatDevStaData basedataMontPatDevStaData) {
        return this.basedataMontPatdevstadataMapper.updateBasedataMontPatDevStaData(basedataMontPatDevStaData);
    }

    public int deleteBasedataMontPatDevStaDataByMontPatDevStaDataIds(Long[] montPatDevStaDataIds) {
        return this.basedataMontPatdevstadataMapper.deleteBasedataMontPatDevStaDataByMontPatDevStaDataIds(montPatDevStaDataIds);
    }

    public int deleteBasedataMontPatDevStaDataByMontPatDevStaDataId(Long montPatDevStaDataId) {
        return this.basedataMontPatdevstadataMapper.deleteBasedataMontPatDevStaDataByMontPatDevStaDataId(montPatDevStaDataId);
    }
}
